import { Component, OnInit } from '@angular/core';
import { HttpResponse } from '@angular/common/http';
import { NgbModal } from '@ng-bootstrap/ng-bootstrap';

import { IWatchListEntry } from '../watch-list-entry.model';
import { WatchListEntryService } from '../service/watch-list-entry.service';
import { WatchListEntryDeleteDialogComponent } from '../delete/watch-list-entry-delete-dialog.component';

@Component({
  selector: 'jhi-watch-list-entry',
  templateUrl: './watch-list-entry.component.html',
})
export class WatchListEntryComponent implements OnInit {
  watchListEntries?: IWatchListEntry[];
  isLoading = false;

  constructor(protected watchListEntryService: WatchListEntryService, protected modalService: NgbModal) {}

  loadAll(): void {
    this.isLoading = true;

    this.watchListEntryService.query().subscribe({
      next: (res: HttpResponse<IWatchListEntry[]>) => {
        this.isLoading = false;
        this.watchListEntries = res.body ?? [];
      },
      error: () => {
        this.isLoading = false;
      },
    });
  }

  ngOnInit(): void {
    this.loadAll();
  }

  trackId(index: number, item: IWatchListEntry): number {
    return item.id!;
  }

  delete(watchListEntry: IWatchListEntry): void {
    const modalRef = this.modalService.open(WatchListEntryDeleteDialogComponent, { size: 'lg', backdrop: 'static' });
    modalRef.componentInstance.watchListEntry = watchListEntry;
    // unsubscribe not needed because closed completes on modal close
    modalRef.closed.subscribe(reason => {
      if (reason === 'deleted') {
        this.loadAll();
      }
    });
  }
}
