import { Component, OnInit } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { ExerciseService } from 'app/exercise/service/exercise.service';
import { ExtendedSearchResultDTO } from 'app/shared/model/search/search-result-dto.model';

@Component({
  selector: 'jhi-exercisePage',
  styleUrls: ['./exercise.component.scss'],
  templateUrl: './exercise.component.html',
})
export class ExerciseComponent implements OnInit {
  exerciseId = '';
  exercise?: ExtendedSearchResultDTO;
  errorMessage: string | null = null;

  constructor(private activatedRoute: ActivatedRoute, private exerciseService: ExerciseService) {}

  ngOnInit(): void {
    this.activatedRoute.data.subscribe(({ pagePath }) => {
      this.exerciseId = pagePath;
      this.exerciseService.loadExercise(this.exerciseId).subscribe({
        next: searchResult => {
          this.exercise = this.exerciseService.populateExerciseWithData(searchResult);
          this.errorMessage = null;
        },
        error: error => {
          if (error.status == 404) this.errorMessage = 'exercise.notFound';
          if (error.status == 403) this.errorMessage = 'exercise.notAccessible';
        },
      });
    });
  }
}
