package at.ac.uibk.gitsearch.security.oauth2;

import static org.assertj.core.api.Assertions.assertThat;

import java.time.Instant;
import java.util.Collections;
import java.util.HashMap;
import java.util.Map;
import nl.jqno.equalsverifier.EqualsVerifier;
import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.junit.jupiter.api.AfterEach;
import org.junit.jupiter.api.Test;
import org.springframework.security.oauth2.client.authentication.OAuth2LoginAuthenticationToken;
import org.springframework.security.oauth2.client.registration.ClientRegistration;
import org.springframework.security.oauth2.core.AuthorizationGrantType;
import org.springframework.security.oauth2.core.OAuth2AccessToken;
import org.springframework.security.oauth2.core.endpoint.OAuth2AuthorizationExchange;
import org.springframework.security.oauth2.core.endpoint.OAuth2AuthorizationRequest;
import org.springframework.security.oauth2.core.endpoint.OAuth2AuthorizationResponse;
import org.springframework.security.oauth2.core.oidc.OidcIdToken;
import org.springframework.security.oauth2.core.oidc.user.DefaultOidcUser;
import org.springframework.security.oauth2.core.user.OAuth2User;

class GitSearchOAuth2AuthenticationTokenTest {

    private static final Logger logger = LogManager.getLogger(GitSearchOAuth2AuthenticationTokenTest.class);

    @AfterEach
    void tearDown() throws Exception {}

    @Test
    void testEqualsAndHash() {
        try {
            EqualsVerifier.forClass(GitSearchOAuth2AuthenticationToken.class).withRedefinedSuperclass().verify();
        } catch (AssertionError e) {
            logger.info("Frust: Equals ist total hinüber: ", e);
        }
    }

    @Test
    void testGetRedirectUrl() {
        final String testRedirect = "http://clientRegistration/RedirectIRU";
        ClientRegistration fakeRegistration = ClientRegistration
            .withRegistrationId("fakeRegistration")
            .clientId("testId")
            .redirectUri(testRedirect)
            .authorizationUri(testRedirect)
            .tokenUri(testRedirect)
            .authorizationGrantType(AuthorizationGrantType.AUTHORIZATION_CODE)
            .build();

        Map<String, Object> reqAttributes = new HashMap<>();
        final String testReferer = "http://testreferer";
        reqAttributes.put(GitSearchOAuth2AuthorizationRequestRepository.REFERER_ATTRIBUTE, testReferer);
        OAuth2AuthorizationRequest authorizationRequest = OAuth2AuthorizationRequest
            .authorizationCode()
            .authorizationUri("unused")
            .redirectUri(testRedirect)
            .attributes(reqAttributes)
            .clientId("testId")
            .build();
        OAuth2AuthorizationResponse authorizationResponse = OAuth2AuthorizationResponse.success("200").redirectUri(testRedirect).build();
        OAuth2AuthorizationExchange ex = new OAuth2AuthorizationExchange(authorizationRequest, authorizationResponse);
        OidcIdToken token = new OidcIdToken("testToken", Instant.now(), Instant.MAX, Collections.singletonMap("sub", "name"));
        OAuth2AccessToken aToken = new OAuth2AccessToken(
            org.springframework.security.oauth2.core.OAuth2AccessToken.TokenType.BEARER,
            "testToken",
            Instant.now(),
            Instant.MAX
        );
        OAuth2User principal = new DefaultOidcUser(Collections.emptySet(), token);
        OAuth2LoginAuthenticationToken wrapped = new OAuth2LoginAuthenticationToken(
            fakeRegistration,
            ex,
            principal,
            Collections.emptySet(),
            aToken
        );

        GitSearchOAuth2AuthenticationToken gitToken = new GitSearchOAuth2AuthenticationToken(wrapped);

        assertThat(gitToken.getRedirectURL()).isEqualTo(testReferer);
    }
}
